# == Class: omsa
#
# Puppet module to install, deploy and configure omsa.
#
class omsa (
  $package           = true,
  $service           = true,
  $enable            = true,
  $force             = false,
  $omsa_package_name = $omsa::params::omsa_package_name,
  $omsa_service_name = $omsa::params::omsa_service_name
) inherits omsa::params {
  case $package {
    true    : { $ensure_package = 'present' }
    false   : { $ensure_package = 'purged' }
    latest  : { $ensure_package = 'latest' }
    default : { fail('package must be true, false or lastest') }
  }

  case $service {
    true    : { $ensure_service = 'running' }
    false   : { $ensure_service = 'stopped' }
    default : { fail('service must be true or false') }
  }

  if ($::is_virtual == false) and
  ($::manufacturer == 'Dell Inc.') or
  ($force == true) {
    class { 'omsa::repos': }

    package { $omsa_package_name:
      ensure  => $ensure_package,
      require => [ Class['omsa::repos'] ],
    }

    service { $omsa_service_name:
      ensure     => $ensure_service,
      enable     => $enable,
      hasrestart => true,
      hasstatus  => true,
      require    => Package[$omsa_package_name],
    }

    file { '/usr/sbin/omreport':
      ensure  => symlink,
      path    => '/usr/sbin/omreport',
      target  => '/opt/dell/srvadmin/bin/omreport',
      require => Package[$omsa_package_name],
    }

    file { '/etc/dell':
      ensure  => symlink,
      path    => '/etc/dell',
      target  => '/etc/opt/dell',
      require => Package[$omsa_package_name],
    }

    # if ($service == true) {
    #   exec { '/etc/init.d/dataeng enablesnmp ':
    #     command     => '/etc/init.d/dataeng enablesnmp ',
    #     refreshonly => true,
    #     notify      => Service[$omsa_service_name],
    #     require     => Package[$omsa_package_name],
    #   }
    # }
  }
}
# EOF
