# == Class: omsa::repos
#
# This is a container class holding default parameters for omsa module.
#
# http://linux.dell.com/repo/community/
#
class omsa::repos {
  $linux_dell = 'http://linux.dell.com/repo/community'

  case $::operatingsystem {
    /(?i:debian|devuan|ubuntu)/: {
      case $::lsbdistcodename {
        # Debian
        'squeeze'         : {
          $location = 'http://linux.dell.com/repo'
          $release  = '/'
          $repos    = ''
        }
        'wheezy'          : {
          $location = "${linux_dell}/debian"
          $release  = $::lsbdistcodename
          $repos    = 'openmanage'
        }
        'jessie'          : {
          $location = "${linux_dell}/debian"
          $release  = $::lsbdistcodename
          $repos    = 'openmanage/840'
        }
        'stretch'         : {
          $location = "${linux_dell}/debian"
          $release  = 'jessie'
          $repos    = 'openmanage/840'
        }
        /(buster|n\/a)/    : {
          $location = "${linux_dell}/debian"
          $release  = 'jessie'
          $repos    = 'openmanage/840'
        }
        # Ubuntu
        'lucid'           : {
          $location = "${linux_dell}/ubuntu"
          $release  = $::lsbdistcodename
          $repos    = 'openmanage'
        }
        'precise'         : {
          $location = "${linux_dell}/ubuntu"
          $release  = $::lsbdistcodename
          $repos    = 'openmanage'
        }
        'trusty'          : {
          $location = "${linux_dell}/ubuntu"
          $release  = $::lsbdistcodename
          $repos    = 'openmanage/840'
        }
        'xenial'          : {
          $location = "${linux_dell}/ubuntu"
          $release  = $::lsbdistcodename
          $repos    = 'openmanage/840'
        }
        default           : {
          $location = "${linux_dell}/debian"
          $release  = $::lsbdistcodename
          $repos    = 'openmanage'
        }
      }

      if !defined(Class['apt']) {
        include apt
      }

      apt::source { 'omsa':
        ensure   => present,
        location => $location,
        release  => $release,
        repos    => $repos,
        key      => '42550ABD1E80D7C1BC0BAD851285491434D8786F',
      }
    }
    /(?i:centos|fedora|redhat)/: {
      file { '/etc/yum.repos.d/omsa.repo':
        ensure  => present,
        backup  => true,
        content => template('omsa/omsa.repo.erb'),
        owner   => 'root',
        group   => 'root',
        mode    => '0644',
      }

      exec { 'yum update':
        command   => 'yum update -q -y',
        path      => [ '/usr/bin', '/usr/sbin', '/bin', '/sbin' ],
        subscribe => File['/etc/yum.repos.d/omsa.repo'],
      }
    }
    default              : {
      fail("Module ${module_name} is not supported on ${::operatingsystem}")
    }
  }
}
# EOF
